@@ -303,7 +303,7 @@ def enhance_by_dtus_and_next_E(df):
     return df
 
 #----------------------------------------------------------------------
-def pd_detect_zeroes(df, channel,  TIMEWIN_US = 25  ):
+def pd_detect_zeroes(df, channel,  TIMEWIN_US = 4.2 ):
     """
    1-get the channel only
    2-dtus
@@ -312,40 +312,52 @@ def pd_detect_zeroes(df, channel,  TIMEWIN_US = 25  ):
       2nd phase - SZ and DZ - make one event from these PILEUPs
       3rd phase - create
     """
-    print( "D.. detecting zeroes")
+    print( f"D.. detecting zeroes: WINDOW == {TIMEWIN_US} us")
     print( freemem() )
 
     # this oneliner doesnt occupy memory ---------------
     # print("D... searching for correlations")
-    dzeroes = len( df.loc[ ((df.E==0) & (df.next_E==0)) & (df.dtus<TIMEWIN_US) ])
-    #df_dz = df.loc[ ((df.E==0) & (df.next_E==0)) & (df.dtus<TIMEWIN_US) ]
-    #dzeroes = len(df_dz)
+
+    dfz = df[:-1]
+
+    dzeroes = len( dfz.loc[ ((dfz.E==0) & (dfz.next_E==0)) & (dfz.dtus<TIMEWIN_US) ])
     print(freemem() )
 
-    szeroes = len( df.loc[ ((df.E!=0) & (df.next_E==0)) & (df.dtus<TIMEWIN_US) ] )
+    # tzeroes = len( dfz.loc[ ((dfz.E==0) & (dfz.next_E==0)) & (dfz.dtus<TIMEWIN_US) ])
+    # print(freemem() )
+
+    szeroes = len( dfz.loc[ ((dfz.E!=0) & (dfz.next_E==0)) & (dfz.dtus<TIMEWIN_US) ] )
+
+    DFszeroes =  dfz.loc[ ((dfz.E!=0) & (dfz.next_E==0)) & (dfz.dtus<TIMEWIN_US) ]
+    print( DFszeroes )
+
     #szeroes = len(df_sz)
     print(freemem() )
 
-    izeroes = len( df.loc[ ((df.E==0) & (df.next_E!=0)) & (df.dtus<TIMEWIN_US) ] )
+    izeroes = len( dfz.loc[ ((dfz.E==0) & (dfz.next_E!=0)) & (dfz.dtus<TIMEWIN_US) ] )
     #izeroes = len(df_iz)
     print(freemem() )
 
 
     print(f"D... ---------------------- START of zero detection ch={channel}")
-    zeroes = len( df.loc[ (df.E==0) & (df.ch==channel)] )
-    zeroes2 = len( df[ (df.E==0) & (df.ch==channel)] )
+    zeroes = len( dfz.loc[ (dfz.E==0) & (dfz.ch==channel)] )
+    zeroes2 = len( dfz[ (dfz.E==0) & (dfz.ch==channel)] )
     #zeroes = len(df_z)
     print(freemem() )
 
 
     print(f"D... total  zeroes (chan={channel}) = {zeroes} which is  {zeroes/len(df)*100:5.2f}%")
     print(f"D... total  zeroes (chan={channel}) = {zeroes2} which is  {zeroes2/len(df)*100:5.2f}%")
+
+    #print(f"D... triple zeroes (chan={channel}) = {tzeroes} which is  {tzeroes/len(df)*100:5.2f}%")
+
     print(f"D... double zeroes (chan={channel}) = {dzeroes} which is  {dzeroes/len(df)*100:5.2f}%")
     #print(df_dz)
     print(f"D... single zeroes (chan={channel}) = {szeroes} which is  {szeroes/len(df)*100:5.2f}%")
     #print(df_sz)
     print(f"D... ilogic zeroes (chan={channel}) = {izeroes} which is  {izeroes/len(df)*100:5.2f}%")
     #print(df_iz)
+    print("D...  There REMAINS ",  zeroes -  dzeroes*2," zeroes that are NOT DOUBLE"  )
     print("D... ______________________ end of zero detection")
 
 
