@@ -264,7 +264,11 @@ def coincidences(filename, ch0, ch1,  tree = False, TIMESHIFT = 2):
     hname = general.generate_hname(filename, ch0)+f"_coin{ch1}"
     outfile = bname+f"_{ch0}_coin{ch1}"+".txt"
     #*************
-    his = general.column_to_histo(  df1['dtus']  , binmax=int(2*TIMESHIFT*100), himax=2*TIMESHIFT, savename= outfile, hname = hname, writeondisk = True, writetxt = False) # 500 for 2us is exactly channel by channel
+    his = general.column_to_histo(  df1['dtus']  , binmax=int(2*TIMESHIFT*100),
+                                    himax=2*TIMESHIFT,
+                                    savename= outfile,
+                                    hname = hname,
+                                    writeondisk = True, writetxt = False) # 500 for 2us is exactly channel by channel
 
 
     if tree:
@@ -275,14 +279,25 @@ def coincidences(filename, ch0, ch1,  tree = False, TIMESHIFT = 2):
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
 #=============================== MAIN1 EVA ==================
 def eva_cut_time(filename,  chan, od=0, do=9999999 ,   tree = False):
     """
-    EVA: use: read_vme_offline cut1 filename_with_asc  60 120
+    EVA: use: read_vme_offline cut1 filename_with_asc 0 60 120; Or 0 60 0==cut to 1m pieces
     """
-    # od = 0
-    # do = 999999
-
+    # od = 0              OR  60
+    # do = 999999          and 0 means  60s cuts
 
 
 
@@ -327,14 +342,30 @@ def eva_cut_time(filename,  chan, od=0, do=9999999 ,   tree = False):
         print(f"D... total saturations: ",len( df.loc[ (df['extras']&1)==1]  ) )
     print("D... Emin            :",df['E'].min() )
     print("D... Emax            :",df['E'].max() )
+    print("D... lasttime        :",df['time'].max() )
+
+    #==========--------------------------AUTOMATIC TRICK TO CUT
+    if od!=0:
+        if do==0:
+            last_moment = int(df['time'].max()+od+1)
+            del df
+            for i in range(0, last_moment, od ): #be sure
+                eva_cut_time(filename,  chan, od=i, do=i+od ,   tree = False)
+            print("i... done many cuts; end")
+            return
+    #--------------------------------------- but obviously bad........
+
+
+
 
     if not(chan in chan_available):
         print(f"X... no events in channel {chan}")
         return
 
 
-
-    if (od!=0) and (do<9999999):
+    od_do_name = ""
+    if (od!=0) or (do<9999999):
+        od_do_name = f"_{od:06d}_{do:06d}"
         print()
         print(f"D...  selecting events    from {od}s to {do}s")
         print(f"D...  selecting events    from {od}s to {do}s")
@@ -346,7 +377,7 @@ def eva_cut_time(filename,  chan, od=0, do=9999999 ,   tree = False):
 
         print(df1)
         if len(df1)==0:
-            print("D... no data for channel {chan}")
+            print(f"D... no data for channel {chan}")
             sys.exit(0)
 
     else:
@@ -389,9 +420,10 @@ def eva_cut_time(filename,  chan, od=0, do=9999999 ,   tree = False):
 
 
     # not final
-    stat_columns = ['ch','rate','realT','liveT','deadT','satT','min_dtus','Nzero','Npu','Ndz','Ntot','Nsat','DT%','DT+S%']
+    stat_columns = ['ch','start','rate','realT','liveT','deadT','satT','min_dtus','Nzero','Npu','Nzer','Ntot','Nsat','DT%','DT+S%']
     df_stat = pd.DataFrame( np.nan, index=[0], columns = stat_columns )
     df_stat['ch'] = chan
+    df_stat['start'] = od
     if satu_DT_ch != None:
         df_stat['Nsat'] = satu_n_ch
         df_stat['satT'] = satu_DT_ch
@@ -415,11 +447,15 @@ def eva_cut_time(filename,  chan, od=0, do=9999999 ,   tree = False):
     hname = general.generate_hname(filename, chan)+"_erlang"
     outfile = bname+"erlang_ch"+str(chan)+".txt"
     #*************
-    his = general.column_to_histo(df1['dtus'], binmax=1000, himax=1+int(df1["dtus"].max()),savename = outfile, hname = hname, writeondisk = True, writetxt = False)
+    his = general.column_to_histo(df1['dtus'], binmax=1000, himax=1+int(df1["dtus"].max()),
+                                  savename = outfile,
+                                  hname = hname, writeondisk = True, writetxt = False)
     hname = general.generate_hname(filename, chan)+"_erlang2"
     outfile = bname+"erlang2_ch"+str(chan)+".txt"
     #*************
-    his = general.column_to_histo(df1['dtus'], binmax=1000, himax=100,savename = outfile, hname = hname, writeondisk = True, writetxt = False)
+    his = general.column_to_histo(df1['dtus'], binmax=1000, himax=100,
+                                  savename = outfile,
+                                  hname = hname, writeondisk = True, writetxt = False)
 
 
 
@@ -427,14 +463,22 @@ def eva_cut_time(filename,  chan, od=0, do=9999999 ,   tree = False):
     hname = general.generate_hname(filename, chan)+"_zerotime"
     outfile = bname+"zerotime_ch"+str(chan)+".txt"
     #*************
-    his = general.column_to_histo(  df1.loc[ (df1.E==0)  ]["time"]  , binmax=1+int(df1.iloc[-1]["time"]), himax=1+int(df1.iloc[-1]["time"]), savename = outfile, hname = hname, writeondisk = True, writetxt = False)
+    his = general.column_to_histo(  df1.loc[ (df1.E==0)  ]["time"]  ,
+                                    binmax=1+int(df1.iloc[-1]["time"]),
+                                    himax=1+int(df1.iloc[-1]["time"]),
+                                    savename = outfile,
+                                    hname = hname, writeondisk = True, writetxt = False)
 
 
     #--------------- histogram nonzeroes in time
     hname = general.generate_hname(filename, chan)+"_nzerotime"
     outfile = bname+"nzerotime_ch"+str(chan)+".txt"
     #*************
-    his = general.column_to_histo(  df1["time"].loc[ (df1.E!=0)  ]  , binmax=1+int(df1.iloc[-1]["time"]), himax=1+int(df1.iloc[-1]["time"]), savename = outfile, hname = hname, writeondisk = True, writetxt = False)
+    his = general.column_to_histo(  df1["time"].loc[ (df1.E!=0)  ]  ,
+                                    binmax=1+int(df1.iloc[-1]["time"]),
+                                    himax=1+int(df1.iloc[-1]["time"]),
+                                    savename = outfile,
+                                    hname = hname, writeondisk = True, writetxt = False)
 
 
     if 'extras' in  df1:
@@ -442,14 +486,22 @@ def eva_cut_time(filename,  chan, od=0, do=9999999 ,   tree = False):
         hname = general.generate_hname(filename, chan)+"_saturations"
         outfile = bname+"saturations_ch"+str(chan)+".txt"
         #*************
-        his = general.column_to_histo(  df1["time"].loc[ (df1.prev_satu!=0)  ]  , binmax=1+int(df1.iloc[-1]["time"]), himax=1+int(df1.iloc[-1]["time"]), savename = outfile, hname = hname, writeondisk = True, writetxt = False)
+        his = general.column_to_histo(  df1["time"].loc[ (df1.prev_satu!=0)  ]  ,
+                                        binmax=1+int(df1.iloc[-1]["time"]),
+                                        himax=1+int(df1.iloc[-1]["time"]),
+                                        savename = outfile,
+                                        hname = hname, writeondisk = True, writetxt = False)
 
 
         #--------------- histogram saturations length
         hname = general.generate_hname(filename, chan)+"_satlength"
         outfile = bname+"satlength_ch"+str(chan)+".txt"
         #*************
-        his = general.column_to_histo(  df1["prev_satu"].loc[ (df1.prev_satu!=0)  ]  , binmax=100, himax=1+int(df1["prev_satu"].max()), savename = outfile, hname = hname, writeondisk = True, writetxt = False)
+        his = general.column_to_histo(  df1["prev_satu"].loc[ (df1.prev_satu!=0)  ]  ,
+                                        binmax=100,
+                                        himax=1+int(df1["prev_satu"].max()),
+                                        savename = outfile,
+                                        hname = hname, writeondisk = True, writetxt = False)
 
 
 
@@ -512,7 +564,7 @@ def eva_cut_time(filename,  chan, od=0, do=9999999 ,   tree = False):
      tot events = {len(df1):8d}
      saturations= {satu_DT_ch} s
 
-     DT %       = {deadtpr:.2f} %
+     DT % (zeros= {deadtpr:.2f} %
      DT(inc sat)= {deadtprsat} %
 """
     print(output)
@@ -536,7 +588,7 @@ def eva_cut_time(filename,  chan, od=0, do=9999999 ,   tree = False):
     #    df_stat['tSAT'] =
 
 
-    df_stat['Ndz'] = len_dzeroes+len_szeroes+len_izeroes
+    df_stat['Nzer'] = len_dzeroes+len_szeroes+len_izeroes
 
 #    df_stat = df_stat.round( decimals = 2 )
     df_stat = df_stat.round( decimals = 2 )
@@ -544,7 +596,7 @@ def eva_cut_time(filename,  chan, od=0, do=9999999 ,   tree = False):
     print( tabulate(df_stat, headers='keys',showindex="never"))#, tablefmt='psql'
     print()
 
-    outinfo = os.path.splitext(filename)[0]+f"_ch{chan}.info"
+    outinfo = os.path.splitext(filename)[0]+f"_ch{chan}{od_do_name}.info"
     print(f"D... creating info FILE {outinfo}")
     with open(outinfo,"w") as f:
         f.write(output)
@@ -557,19 +609,22 @@ def eva_cut_time(filename,  chan, od=0, do=9999999 ,   tree = False):
     hname = general.generate_hname(filename, chan)
 
 
-    outfile = bname+f"_ch{chan}.txt"
+    outfile = bname+f"_ch{chan}{od_do_name}.txt"
     #*************
-    his = general.column_to_histo(df2['E'], savename = outfile, hname = hname, writeondisk = True)
-    outfile2 = bname+".asc1"
-    print(f"D... {outfile2} is save as a duplicate")
-    copyfile(outfile, outfile2)
+    his = general.column_to_histo(df2['E'],
+                                  savename = outfile,
+                                  hname = hname, writeondisk = True)
+
+    #outfile2 = bname+".asc1"
+    #print(f"D... {outfile2} is save as a duplicate")
+    #copyfile(outfile, outfile2)
 
     print( general.freemem() )
 
 
     if tree:
         #*************
-        general.save_to_tree(df2, filename, treename = f"df{chan}") # no modname...
+        general.save_to_tree(df1, filename, treename = f"df{chan}") # no modname...
 
     print( general.freemem() )
 
